==> haskell-base64-bytestring-1.0.0.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base64-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base64-bytestring
version: 1.0.0.2
id: base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX
key: base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX
license: BSD-3-Clause
copyright: 2010-2018 Bryan O'\''Sullivan et al.
maintainer: Herbert Valerio Riedel <hvr@gnu.org>,
            Mikhail Glushenkov <mikhail.glushenkov@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/haskell/base64-bytestring
synopsis: Fast base64 encoding and decoding for ByteStrings
description:
    This package provides support for encoding and decoding binary data according to @base64@ (see also <https://tools.ietf.org/html/rfc4648 RFC 4648>) for strict and lazy ByteStrings.
category: Data
abi: 6179f7ac87743d64ca3eaf63a976bc72
exposed: True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.Lazy
    Data.ByteString.Base64.URL Data.ByteString.Base64.URL.Lazy
hidden-modules: Data.ByteString.Base64.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/base64-bytestring-1.0.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/base64-bytestring-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/base64-bytestring-1.0.0.2
hs-libraries: HSbase64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-base64-bytestring/html/base64-bytestring.haddock
haddock-html: /usr/share/doc/haskell-base64-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base64-bytestring-1.0.0.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base64-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base64-bytestring
version: 1.0.0.2
id: base64-bytestring-1.0.0.2-11TO9fSEmuqDlOPx6IouNl
key: base64-bytestring-1.0.0.2-11TO9fSEmuqDlOPx6IouNl
license: BSD-3-Clause
copyright: 2010-2018 Bryan O'\''Sullivan et al.
maintainer: Herbert Valerio Riedel <hvr@gnu.org>,
            Mikhail Glushenkov <mikhail.glushenkov@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/haskell/base64-bytestring
synopsis: Fast base64 encoding and decoding for ByteStrings
description:
    This package provides support for encoding and decoding binary data according to @base64@ (see also <https://tools.ietf.org/html/rfc4648 RFC 4648>) for strict and lazy ByteStrings.
category: Data
abi: 3d6cd49268c5b0ae755f036d29229033
exposed: True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.Lazy
    Data.ByteString.Base64.URL Data.ByteString.Base64.URL.Lazy
hidden-modules: Data.ByteString.Base64.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/base64-bytestring-1.0.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/base64-bytestring-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/base64-bytestring-1.0.0.2
hs-libraries: HSbase64-bytestring-1.0.0.2-11TO9fSEmuqDlOPx6IouNl
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-base64-bytestring/html/base64-bytestring.haddock
haddock-html: /usr/share/doc/haskell-base64-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
